| Type: | Package |
| Title: | Linear, Logistic and Generalized Linear Models Regressions for the EnvWAS/EWAS Approach |
| Version: | 1.0.1 |
| Description: | Tool for Environment-Wide Association Studies (EnvWAS / EWAS) which are repeated analysis. It includes three functions. One function for linear regression, a second for logistic regression and a last one for generalized linear models. |
| Depends: | R (≥ 4.3) |
| Imports: | stats, devtools, dplyr, ggplot2, MASS |
| Suggests: | knitr, rmarkdown, mlbench (≥ 2.1-11) |
| License: | GPL (≥ 3) |
| URL: | https://github.com/EHMarwan/Elja |
| BugReports: | https://github.com/EHMarwan/Elja/issues |
| VignetteBuilder: | knitr |
| Encoding: | UTF-8 |
| Config/roxygen2/version: | 8.1.0 |
| NeedsCompilation: | no |
| Packaged: | 2026-08-24 17:51:03 UTC; marwan_eh |
| Author: | Marwan El Homsi |
| Maintainer: | Marwan El Homsi <marwan_eh@outlook.fr> |
| Repository: | CRAN |
| Date/Publication: | 2026-08-24 19:20:02 UTC |
Generalized Linear Models regression for EnvWAS/EWAS analysis
Description
A tool for Environment-Wide Association Studies (EnvWAS / EWAS) which are repeated analysis. This function is espacially for generalized linear models 'glm' and allows the addition of adjustment variables.
Usage
ELJAglm(
var,
var_adjust = NULL,
family = binomial(link = "logit"),
data,
manplot = TRUE,
nbvalmanplot = 100,
Bonferroni = FALSE,
FDR = FALSE,
manplotsign = FALSE
)
Arguments
var |
A categorical and binary variable. It is generally your outcome. |
var_adjust |
A vector containing the names of the fixed adjustment variables for all the models. |
family |
The family and the link use for the glm function. |
data |
A dataframe containing all the variables needed for the analysis. |
manplot |
Generate a Manhattan plot of the results of the analysis. |
nbvalmanplot |
The number of variables to include in each Manhattan plot. |
Bonferroni |
Add a dashed bar to the Manhattan plot showing the Bonferroni significance threshold. |
FDR |
Add a dashed bar to the Manhattan plot showing the False Discovery Rate (Benjamini-Hochberg method) significance threshold. NA if all p-values > FDR corrected p-values. |
manplotsign |
Generates a Manhattan plot with only significant results (p<0.05). |
Value
A Dataframe with results for each variable of the model.
References
Dunn OJ. Multiple Comparisons Among Means. Journal of the American Statistical Association. 1961;56(293):52‑64. Benjamini Y, Hochberg Y. Controlling the False Discovery Rate: A Practical and Powerful Approach to Multiple Testing. Journal of the Royal Statistical Society: Series B (Methodological). 1995;57(1):289‑300. Leisch F, Dimitriadou E. mlbench: Machine Learning Benchmark Problems. R package version 2.1-11; 2025. Available from: https://CRAN.R-project.org/package=mlbench
Examples
### Loading the synthetic diabetes dataset contained in the mlbench package
library(mlbench)
data(SynthDiabetes)
### Using ELJAlinear to perform EWAS analysis
ELJAglm(var = 'diabetes',data = SynthDiabetes,
family = binomial(link = "logit"), manplot = TRUE, Bonferroni = TRUE,
FDR = TRUE, nbvalmanplot = 30, manplotsign = FALSE)
results
Linear regression for EnvWAS/EWAS analysis
Description
A tool for Environment-Wide Association Studies (EnvWAS / EWAS) namely repeated analyses allowing to estimate the relationships between several environmental factors and a health events. This function is especially for linear regressions and allows the addition of adjustment variables.
Usage
ELJAlinear(
var,
var_adjust = NULL,
data,
manplot = TRUE,
nbvalmanplot = 100,
Bonferroni = FALSE,
FDR = FALSE,
manplotsign = FALSE
)
Arguments
var |
A categorical and binary variable. It is generally your outcome. |
var_adjust |
A vector containing the names of the fixed adjustment variables for all the models. |
data |
A dataframe containing all the variables needed for the analysis. |
manplot |
Generate a Manhattan plot of the results of the analysis. |
nbvalmanplot |
The number of variables to include in each Manhattan plot. |
Bonferroni |
Add a dashed bar to the Manhattan plot showing the Bonferroni significance level. |
FDR |
Add a dashed bar to the Manhattan plot showing the False Discovery Rate (Benjamini-Hochberg method) significance threshold. NA if all p-values > FDR corrected p-values. |
manplotsign |
Generates a Manhattan plot with only significant results (p<0.05). |
Value
A Dataframe with results for each variable of the model.
References
Dunn OJ. Multiple Comparisons Among Means. Journal of the American Statistical Association. 1961;56(293):52‑64. Benjamini Y, Hochberg Y. Controlling the False Discovery Rate: A Practical and Powerful Approach to Multiple Testing. Journal of the Royal Statistical Society: Series B (Methodological). 1995;57(1):289‑300. Leisch F, Dimitriadou E. mlbench: Machine Learning Benchmark Problems. R package version 2.1-11; 2025. Available from: https://CRAN.R-project.org/package=mlbench
Examples
### Loading the synthetic diabetes dataset contained in the mlbench package
library(mlbench)
data(SynthDiabetes)
### Using ELJAlinear to perform EWAS analysis
ELJAlinear(var = 'pregnant',data = SynthDiabetes,manplot = TRUE,
Bonferroni = TRUE,FDR = TRUE, nbvalmanplot = 30, manplotsign = FALSE)
results
Logistic regression tool for EnvWAS/EWAS analysis
Description
A tool for Environment-Wide Association Studies (EnvWAS / EWAS) which are repeated analysis. This function is espacially for logistic regression based on the glm function with a binomial family with a logit link and allows the addition of adjustment variables.
Usage
ELJAlogistic(
var,
var_adjust = NULL,
data,
manplot = TRUE,
nbvalmanplot = 100,
Bonferroni = FALSE,
FDR = FALSE,
manplotsign = FALSE
)
Arguments
var |
A categorical and binary variable. It is generally your outcome. |
var_adjust |
A vector containing the names of the fixed adjustment variables for all the models. |
data |
A dataframe containing all the variables needed for the analysis. |
manplot |
Generate a Manhattan plot of the results of the analysis. |
nbvalmanplot |
The number of variables to include in each Manhattan plot. |
Bonferroni |
Add a dashed bar to the Manhattan plot showing the Bonferroni significance level. |
FDR |
Add a dashed bar to the Manhattan plot showing the False Discovery Rate (Benjamini-Hochberg method) significance threshold. NA if all p-values > FDR corrected p-values. |
manplotsign |
Generates a Manhattan plot with only significant results (p<0.05). |
Value
A Dataframe with results for each variable of the model.
References
Dunn OJ. Multiple Comparisons Among Means. Journal of the American Statistical Association. 1961;56(293):52‑64. Benjamini Y, Hochberg Y. Controlling the False Discovery Rate: A Practical and Powerful Approach to Multiple Testing. Journal of the Royal Statistical Society: Series B (Methodological). 1995;57(1):289‑300. Leisch F, Dimitriadou E. mlbench: Machine Learning Benchmark Problems. R package version 2.1-11; 2025. Available from: https://CRAN.R-project.org/package=mlbench
Examples
### Loading the synthetic diabetes dataset contained in the mlbench package
library(mlbench)
data(SynthDiabetes)
### Using ELJAlinear to perform EWAS analysis
ELJAlogistic(var = 'diabetes',data = SynthDiabetes,manplot = TRUE,
Bonferroni = TRUE,FDR = TRUE, nbvalmanplot = 30, manplotsign = FALSE)
results